@@ -20,15 +20,22 @@ function(pdb, ca.dist=4, blank="X", rtn.vec=TRUE) {
   len <- diff( c(1,ind,length(d)) )
 
   cat(paste("\t Found",length(ind), "possible chain breaks\n"))
-  cat(paste("\t  After resno(s):",
-        paste( pdb$atom[ca$atom,"resno"][(ind)], collapse=", " ),"\n" ))
-  cat(paste("\t  Chain length(s):",
-        paste(len+1, collapse=", " ),"\n" ))
+  if(length(ind) > 0) {
+     cat(paste("\t  After resno(s):",
+           paste( pdb$atom[ca$atom,"resno"][(ind)], collapse=", " ),"\n" ))
+     cat(paste("\t  Chain length(s):",
+           paste(len+1, collapse=", " ),"\n" ))
+  }
 
   ## Make a chain id vector
   if(rtn.vec) {
     resno.ind <- as.numeric(c(1, sort(as.numeric(c(ind,(ind+1)))), (length(d)+1)
 ))
+    ## Renumber residues first, in case that original resnos are not
+    ## consecutive crossing multiple chains
+    res <- paste(pdb$atom[, "chain"], pdb$atom[, "resno"], pdb$atom[, "insert"], sep="_")
+    pdb$atom[, "resno"] <- vec2resno(1:length(unique(res)), res) 
+
     resno.val <- pdb$atom[ca$atom,"resno"][resno.ind]
     resno.val <- matrix(as.numeric(resno.val),nrow=2)
 
